Package 'crossrepotest'

Title: Test R-universe dependencies across multiple repo
Description: Packages living in one R-universe can depend or import packages in others (not CRAN) via Additional_repositories field, like this
Authors: Mark V. Bravington <[email protected]>
Maintainer: Mark V. Bravington <[email protected]>
License: GPL (>=2)
Version: 1.0.7
Built: 2026-05-16 05:54:49 UTC
Source: https://github.com/closekin/crossrepotest

Help Index


Autologous bureaucracy simulator

Description

Does nothing, but takes a long time to do so. Out of the goodness of my heart, I have greatly compressed the runtime.

Usage

bureaucracy_in_action()